@@ -78,55 +78,3 @@ tar_combine <- function(
     cue = cue
   )
 }
-
-tar_combine_impl <- function(
-  name,
-  targets,
-  command,
-  use_names,
-  pattern,
-  packages,
-  library,
-  format,
-  iteration,
-  error,
-  memory,
-  garbage_collection,
-  deployment,
-  priority,
-  resources,
-  storage,
-  retrieval,
-  cue
-) {
-  assert_chr(name)
-  assert_targets(targets)
-  names_chr <- map_chr(targets, ~.x$settings$name)
-  names_sym <- as_symbols(names_chr)
-  if (use_names) {
-    names(names_sym) <- names_chr
-  }
-  command <- tar_tidy_eval(
-    command,
-    envir = list(.x = names_sym),
-    tidy_eval = TRUE
-  )
-  targets::tar_target_raw(
-    name = name,
-    command = command,
-    pattern = pattern,
-    packages = packages,
-    library = library,
-    format = format,
-    iteration = iteration,
-    error = error,
-    memory = memory,
-    garbage_collection = garbage_collection,
-    deployment = deployment,
-    priority = priority,
-    resources = resources,
-    storage = storage,
-    retrieval = retrieval,
-    cue = cue
-  )
-}
