@@ -1,5 +1,6 @@
 #' @title Target with an R Markdown document.
 #' @export
+#' @family Literate programming targets
 #' @description Shorthand to include an R Markdown document in a
 #'   `targets` pipeline.
 #' @details `tar_render()` is an alternative to `tar_target()` for
@@ -31,12 +32,8 @@
 #'   all returned paths are *relative* paths to ensure portability
 #'   (so that the project can be moved from one file system to another
 #'   without invalidating the target).
-#'
-#'   Target objects represent skippable steps of the analysis pipeline
-#'   as described at <https://books.ropensci.org/targets/>.
-#'   Please see the design specification at
-#'   <https://books.ropensci.org/targets-design/>
-#'   to learn about the structure and composition of target objects.
+#'   See the "Target objects" section for background.
+#' @inheritSection tar_map Target objects
 #' @inheritParams targets::tar_target
 #' @inheritParams rmarkdown::render
 #' @param path Character string, file path to the R Markdown source file.
@@ -125,7 +122,7 @@ tar_render <- function(
     envir = envir,
     tidy_eval = tidy_eval
   )
-  tar_target_raw(
+  targets::tar_target_raw(
     name = deparse_language(substitute(name)),
     command = tar_render_command(path, args, quiet),
     packages = packages,
