@@ -1,4 +1,6 @@
 #' @title Target with a custom cancellation condition.
+#' @export
+#' @family targets with custom invalidation rules
 #' @description Create a target that cancels itself if a user-defined
 #'   decision rule is met.
 #' @details `tar_skip()` creates a target that cancels itself
@@ -6,16 +8,11 @@
 #'   is `targets::tar_cancel(your_condition)`, which allows skipping to happen
 #'   even if the target does not exist yet. This behavior differs from
 #'   `tar_cue(mode = "never")`, which still runs if the target does not exist.
-#' @export
 #' @inheritParams targets::tar_target
 #' @return A target object with `targets::tar_cancel(your_condition)` inserted
 #'   into the command.
-#'
-#'   Target objects represent skippable steps of the analysis pipeline
-#'   as described at <https://books.ropensci.org/targets/>.
-#'   Please see the design specification at
-#'   <https://books.ropensci.org/targets-design/>
-#'   to learn about the structure and composition of target objects.
+#'   See the "Target objects" section for background.
+#' @inheritSection tar_map Target objects
 #' @param skip R code for the skipping condition. If it evaluates to `TRUE`
 #'   during `tar_make()`, the target will cancel itself.
 #' @param tidy_eval Whether to invoke tidy evaluation
@@ -57,7 +54,7 @@ tar_skip <- function(
   skip <- tar_tidy_eval(substitute(skip), envir, tidy_eval)
   skip <- as.call(list(call_ns("targets", "tar_cancel"), skip))
   command <- call_brace(list(skip, command))
-  tar_target_raw(
+  targets::tar_target_raw(
     name = name,
     command = command,
     pattern = NULL,
