@@ -1,17 +1,17 @@
 throw_validate <- function(...) {
-  stop(condition_validate(...))
+  stop(tar_condition_validate(...))
 }
 
 warn_validate <- function(...) {
   warning(warning_validate(...))
 }
 
-condition_validate <- function(...) {
+tar_condition_validate <- function(...) {
   structure(
     list(message = paste0(..., collapse = ""), call = NULL),
     class = c(
-      "condition_validate",
-      "condition_tarchetypes",
+      "tar_condition_validate",
+      "tar_condition_tarchetypes",
       "error",
       "condition"
     )
@@ -22,8 +22,8 @@ warning_validate <- function(...) {
   structure(
     list(message = paste0(..., collapse = ""), call = NULL),
     class = c(
-      "condition_validate",
-      "condition_targets",
+      "tar_condition_validate",
+      "tar_condition_targets",
       "warning",
       "condition"
     )
